# Tutorial: Managing IT Risks Associated with Data Center and Server Locations
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations#overview)
  * [Prerequisite: Build an Application Inventory in SAP LeanIX](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations#prerequisite:-build-an-application-inventory-in-sap-leanix)
  * [Step 1: Build an IT Component Repository](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations#step-1:-build-an-it-component-repository)
  * [Step 2: Add the Software Versions and Assess Risk and Suitability](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations#step-2:-add-the-software-versions-and-assess-risk-and-suitability)
  * [Step 3: Import Data Center and Server Location Information](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations#step-3:-import-data-center-and-server-location-information)
  * [Step 4: Link IT Components to Application Fact Sheets](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations#step-4:-link-it-components-to-application-fact-sheets)
  * [Step 5: Analyze and Mitigate Risks](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations#step-5:-analyze-and-mitigate-risks)


This is an example tutorial on managing the impact of data center and server location on risk mitigation and compliance using SAP LeanIX Technology Risk and Compliance.
